==> dde-calendar_1.2.5.orig.tar.gz: dde-calendar-1.2.5/CHANGELOG.md <==
<a name="1.2.5"></a>
### 1.2.5 (2018-08-07)




<a name="1.2.4"></a>
### 1.2.4 (2018-07-31)


#### Features

*   set window title ([e1e7efad](https://github.com/linuxdeepin/dde-calendar/commit/e1e7efadb1b5c0ec9e5ca068236fee43492c260f))



<a name="1.2.3"></a>
### 1.2.3 (2018-05-25)


#### Bug Fixes

*   register user scope single instance ([87664c8e](https://github.com/linuxdeepin/dde-calendar/commit/87664c8ef7efce224601bdfa3ca58728b41552a3))
*   not refresh day when direct switch month ([20d35339](https://github.com/linuxdeepin/dde-calendar/commit/20d3533960c4818c5123958c619cb656a2b219b5))



<a name="1.2.2"></a>
### 1.2.2 (2018-03-22)


#### Features

*   Add acknowledgement link ([f491e7db](https://github.com/linuxdeepin/dde-calendar/commit/f491e7dbd7a007f5df339ca15fe024c5da455ea9))



<a name="1.2.1"></a>
### 1.2.1 (2018-03-09)


#### Bug Fixes

*   calendar not update current Lunar ([bab3f2a5](https://github.com/linuxdeepin/dde-calendar/commit/bab3f2a59918dff3c5898f749cb1f096a74f2997))



<a name=""></a>
##  1.2.0 (2018-03-07)


#### Features

* **version:**  correct version number ([8a30944f](https://github.com/linuxdeepin/dde-calendar/commit/8a30944f01d93ee2946eac65011998fe5c63ab54))

#### Bug Fixes

*   not update current lunar date with first run ([8046c2c2](https://github.com/linuxdeepin/dde-calendar/commit/8046c2c2518e70b4ac576a2df04d5aec03fdd48d))
*   Adapt lintian ([199bdd4d](https://github.com/linuxdeepin/dde-calendar/commit/199bdd4db809e17ab15d55b3736e8afdf2f221b5))
* **debian:**  add dde-api depend ([fd2b0bbc](https://github.com/linuxdeepin/dde-calendar/commit/fd2b0bbc1450515e5a1632a7ba1995a36521198a))
* **window:**  change buttonrelease to buttonpress event ([0af2c8b2](https://github.com/linuxdeepin/dde-calendar/commit/0af2c8b2c227db6700b0c619ac4a1ebf304562fa))



<a name="1.1.1"></a>
### 1.1.1 (2017-11-16)




<a name=""></a>
##  1.1.0 (2017-11-03)


#### Features

* **hidpi:**  support hidpi ([4ac3d23d](https://github.com/linuxdeepin/dde-session-ui/commit/4ac3d23d41bfa32be69b67357b2821df45cdcb69))

==> dde-calendar_1.2.6.orig.tar.gz: dde-calendar-1.2.6/CHANGELOG.md <==
<a name="1.2.6"></a>
### 1.2.6 (2018-11-23)


#### Features

*   add genericName ([3ca6204e](https://github.com/linuxdeepin/dde-calendar/commit/3ca6204e03af1d5e402ec31d3bad8785288bdf3d))



<a name="1.2.5"></a>
### 1.2.5 (2018-08-07)




<a name="1.2.4"></a>
### 1.2.4 (2018-07-31)


#### Features

*   set window title ([e1e7efad](https://github.com/linuxdeepin/dde-calendar/commit/e1e7efadb1b5c0ec9e5ca068236fee43492c260f))



<a name="1.2.3"></a>
### 1.2.3 (2018-05-25)


#### Bug Fixes

*   register user scope single instance ([87664c8e](https://github.com/linuxdeepin/dde-calendar/commit/87664c8ef7efce224601bdfa3ca58728b41552a3))
*   not refresh day when direct switch month ([20d35339](https://github.com/linuxdeepin/dde-calendar/commit/20d3533960c4818c5123958c619cb656a2b219b5))



<a name="1.2.2"></a>
### 1.2.2 (2018-03-22)


#### Features

*   Add acknowledgement link ([f491e7db](https://github.com/linuxdeepin/dde-calendar/commit/f491e7dbd7a007f5df339ca15fe024c5da455ea9))



<a name="1.2.1"></a>
### 1.2.1 (2018-03-09)


#### Bug Fixes

*   calendar not update current Lunar ([bab3f2a5](https://github.com/linuxdeepin/dde-calendar/commit/bab3f2a59918dff3c5898f749cb1f096a74f2997))



<a name=""></a>
##  1.2.0 (2018-03-07)


#### Features

* **version:**  correct version number ([8a30944f](https://github.com/linuxdeepin/dde-calendar/commit/8a30944f01d93ee2946eac65011998fe5c63ab54))

#### Bug Fixes

*   not update current lunar date with first run ([8046c2c2](https://github.com/linuxdeepin/dde-calendar/commit/8046c2c2518e70b4ac576a2df04d5aec03fdd48d))
*   Adapt lintian ([199bdd4d](https://github.com/linuxdeepin/dde-calendar/commit/199bdd4db809e17ab15d55b3736e8afdf2f221b5))
* **debian:**  add dde-api depend ([fd2b0bbc](https://github.com/linuxdeepin/dde-calendar/commit/fd2b0bbc1450515e5a1632a7ba1995a36521198a))
* **window:**  change buttonrelease to buttonpress event ([0af2c8b2](https://github.com/linuxdeepin/dde-calendar/commit/0af2c8b2c227db6700b0c619ac4a1ebf304562fa))



<a name="1.1.1"></a>
### 1.1.1 (2017-11-16)




<a name=""></a>
##  1.1.0 (2017-11-03)


#### Features

* **hidpi:**  support hidpi ([4ac3d23d](https://github.com/linuxdeepin/dde-session-ui/commit/4ac3d23d41bfa32be69b67357b2821df45cdcb69))
